@@ -29,30 +29,59 @@ from aiohttp_sqlalchemy.utils import (
 from aiohttp_sqlalchemy.views import (
     SAAbstractView,
     SABaseView,
+    SAInstanceAddMixin,
+    SAInstanceDeleteMixin,
+    SAInstanceEditMixin,
     SAInstanceMixin,
     SAInstanceView,
+    SAInstanceViewMixin,
     SAItemMixin,
     SAItemView,
+    SAListAddMixin,
+    SAListDeleteMixin,
+    SAListEditMixin,
+    SAListMixin,
+    SAListViewMixin,
     SAMixin,
+    SAModelDeleteMixin,
+    SAModelEditMixin,
     SAModelMixin,
     SAModelView,
+    SAModelViewMixin,
+    SAPrimaryKeyMixin,
     SAView,
 )
 
-__version__ = '0.21.0'
+__version__ = '0.22.0.post0'
 
 __all__ = [
-    'SA_DEFAULT_KEY',
+    'DEFAULT_KEY',
     'DuplicateAppKeyError',
     'DuplicateRequestKeyError',
+    'SAAbstractView',
     'SABaseView',
+    'SA_DEFAULT_KEY',
+    'SAInstanceAddMixin',
+    'SAInstanceDeleteMixin',
+    'SAInstanceEditMixin',
     'SAInstanceMixin',
     'SAInstanceView',
+    'SAInstanceViewMixin',
     'SAItemMixin',
     'SAItemView',
+    'SAListAddMixin',
+    'SAListDeleteMixin',
+    'SAListEditMixin',
+    'SAListMixin',
+    'SAListViewMixin',
     'SAMixin',
+    'SAModelDeleteMixin',
+    'SAModelEditMixin',
     'SAModelMixin',
     'SAModelView',
+    'SAModelViewMixin',
+    'SAPrimaryKeyMixin',
+    'SAView',
     'bind',
     'get_session',
     'get_session_factory',
